import { Client, GatewayIntentBits, Collection, EmbedBuilder } from 'discord.js'
import fs from 'node:fs'
import path from 'node:path'
import { config } from './config'

const client = new Client({
  intents: [GatewayIntentBits.Guilds, GatewayIntentBits.GuildMembers, GatewayIntentBits.GuildMessages, GatewayIntentBits.MessageContent]
})

const createEmbed = (description: string) => {
  return new EmbedBuilder()
    .setColor(config.EMBED_COLOR)
    .setDescription(description);
};

client.commands = new Collection()

const commandsPath = path.join(__dirname, 'commands');
const commandFiles = fs.readdirSync(commandsPath).filter(file => file.endsWith('.ts'));

for (const file of commandFiles) {
  const filePath = path.join(commandsPath, file);
  const command = require(filePath);

  if ('data' in command && 'execute' in command) {
    client.commands.set(command.data.name, command);
  } else {
    console.error(`The command at ${filePath} is missing a required "data" or "execute" property.`);
  }
}

const eventsPath = path.join(__dirname, 'events');
const eventFiles = fs.readdirSync(eventsPath).filter(file => file.endsWith('.ts'));

for (const file of eventFiles) {
  const filePath = path.join(eventsPath, file);
  const event = require(filePath);
  if (event.once) {
    client.once(event.name, (...args) => event.execute({ client, createEmbed }, ...args));
  } else {
    client.on(event.name, (...args) => event.execute({ client, createEmbed }, ...args));
  }
}

client.login(config.DISCORD_TOKEN);
